@@ -11,7 +11,7 @@ class ProjectModule(ProjectModule):
     description = 'Clyde is a command line interface designer.'
     development_requires = ['packgram>=0.23']
     github_user = 'respect31'
-    install_requires = ['jinja2', 'box>=0.44']
+    install_requires = ['box>=0.44', 'jinja2']
     interpreters = ['3.3', '3.4']
     license = 'MIT License'
     name = 'clyde'
@@ -19,4 +19,4 @@ class ProjectModule(ProjectModule):
     pypi_password_secure = 'bjVGVG2Gkj9vm65t0BwVqGRTqi6o2qqOFVCo6X7KCfZdrBdL2u7EaNpDqhj8//ITpn5bZsnPWmLXuZEhhStc/kbJpMOgfciIuSZW6IChTiFnUgwK/F/yndhD7G0D6n6hbQ/mCT7KPaH3omZWspjcNdhyhn/NaWD9mZbhrcmPLN8='
     tests_require = ['nose', 'coverage']
     test_suite = 'nose.collector'
-    version = '0.3.0'
+    version = '0.4.0'
